@@ -62,18 +62,20 @@ getTeamBowlingDetails <- function(team,dir=".",save=FALSE,odir="."){
     fl <- Sys.glob(a)
     bowlingDetails <- NULL
     for(i in 1:length(fl)){
-        load(fl[i])
-        match <- overs
-        details <- teamBowlingPerfDetails(match,team,includeInfo=TRUE)
-        # If the side has not batted details will be NULL. Skip in that case
-        if(!is.null(dim(details))){
-            bowlingDetails <- rbind(bowlingDetails,details)
-        }else {
-            #print("Empty")
-
-            next
-        }
+        # Add try-catch to handle issues
+        tryCatch({
+            load(fl[i])
+            match <- overs
+            details <- teamBowlingPerfDetails(match,team,includeInfo=TRUE)
+            # If the side has not batted details will be NULL. Skip in that case
+            if(!is.null(dim(details))){
+                bowlingDetails <- rbind(bowlingDetails,details)
+            }else {
+                #print("Empty")
 
+                next
+            }
+        }, error=function(e){cat("ERROR :",conditionMessage(e), "\n")})
     }
 
     if(save==TRUE){
